@@ -8,18 +8,19 @@ use Tickit::Widget::ScrollBox;
 use Tickit::Widget::GridBox;
 use Tickit::Widget::Static;
 
+my $gridbox = Tickit::Widget::GridBox->new(
+   row_spacing => 1,
+   col_spacing => 2,
+);
+foreach my $row ( 1 .. 10 ) {
+   $gridbox->append_row(
+      [ map { Tickit::Widget::Static->new( text => "Row $row Col $_" ) } 1 .. 10 ]
+   );
+}
+
 my $scrollbox = Tickit::Widget::ScrollBox->new(
    horizontal => "on_demand",
    vertical   => "on_demand",
-
-   child => Tickit::Widget::GridBox->new(
-      children => [
-         map { my $row = $_;
-               [ map { Tickit::Widget::Static->new( text => "Row $row Col $_" ) } 1 .. 10 ]
-             } 1 .. 10 ],
-      row_spacing => 1,
-      col_spacing => 2,
-   ),
-);
+)->set_child( $gridbox );
 
 Tickit->new( root => $scrollbox )->run;
